Welcome to ClientVPS Mirrors

Help for package StabilityApp
Type: Package
Title: Stability Analysis App for GEI in Multi-Environment Trials
Version: 0.1.0
Maintainer: Muhammad Yaseen <myaseen208@gmail.com>
Description: Provides tools for Genotype by Environment Interaction (GEI) analysis, using statistical models and visualizations to assess genotype performance across environments. It helps researchers explore interaction effects, stability, and adaptability in multi-environment trials, identifying the best-performing genotypes in different conditions. Which Win Where!
Depends: R (≥ 4.1)
Imports: dplyr, DT, gridExtra, patchwork, stability, shiny, shinyBS, shinydashboardPlus
Suggests: shinytest2, testthat (≥ 3.0.0)
License: GPL-3
RoxygenNote: 7.3.2
Encoding: UTF-8
Note: School of Mathematical & Statistical Sciences, Clemson University, Clemson, South Carolina, USA
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2024-10-29 11:04:29 UTC; myaseen208
Author: Muhammad Yaseen ORCID iD [aut, cre, cph], Kent M. Eskridge [aut, ctb]
Repository: CRAN
Date/Publication: 2024-11-01 14:30:19 UTC

StabilityApp

Description

StabilityApp

Value

output of stability R package

Examples

if(interactive()) {
    library(StabilityApp)
    StabilityApp()
  }

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.